.. image:: ../artwork/cicada.png
    :width: 200px
    :align: right

.. _python-api:

API Reference
=============

.. toctree::
    :maxdepth: 2

    cicada.rst
    cicada.active.rst
    cicada.additive.rst
    cicada.arithmetic.rst
    cicada.calculator.rst
    cicada.cli.rst
    cicada.cli.main.rst
    cicada.cli.perf.rst
    cicada.communicator.rst
    cicada.communicator.interface.rst
    cicada.communicator.socket.rst
    cicada.communicator.socket.connect.rst
    cicada.encoding.rst
    cicada.interactive.rst
    cicada.logger.rst
    cicada.przs.rst
    cicada.shamir.rst
    cicada.transcript.rst
